:notoc:

********************
suppy documentation
********************

**Date**: |today| **Version**: |version|

**THE DOCUMENTATION IS STILL UNDER CONSTRUCTION**

.. grid:: 1 2 2 2
    :gutter: 4
    :padding: 2 2 0 0
    :class-container: sd-text-center



    .. grid-item-card:: Installation
        :class-card: intro-card
        :shadow: md

        +++

        .. button-ref:: installation
            :ref-type: ref
            :click-parent:
            :color: secondary
            :expand:

            To the installation guide

    .. grid-item-card:: User guide
        :class-card: intro-card
        :shadow: md

        +++

        .. button-ref:: user_guide
            :ref-type: ref
            :click-parent:
            :color: secondary
            :expand:

            To the user guides



    .. grid-item-card:: Api
        :class-card: intro-card
        :shadow: md

        +++

        .. button-ref:: api_documentation
            :ref-type: ref
            :click-parent:
            :color: secondary
            :expand:

            To the api documentation


    .. grid-item-card:: Help and support
        :class-card: intro-card
        :shadow: md

        +++

        .. button-ref:: help
            :ref-type: ref
            :click-parent:
            :color: secondary
            :expand:

            To the help and support

.. toctree::
      :maxdepth: 1
      :hidden:
      :titlesonly:

      api/index
      installation/installation
      user_guide/general_intro
      help/help
